@@ -3,10 +3,12 @@ use serde::{Deserialize, Serialize};
 use std::{fmt::Debug, fs::read_to_string, path::Path};
 
 #[derive(Clone, Debug, Serialize, Deserialize)]
+#[serde(rename_all = "snake_case")]
 pub enum ContentType {
     Text,
     Image,
-    Number,
+    Reference,
+    List,
 }
 
 #[derive(Clone, Debug, Deserialize, Serialize)]
@@ -43,6 +45,7 @@ pub struct Field {
     pub name: String,
     #[serde(rename = "type")]
     pub content_type: ContentType,
+    pub of: Option<String>,
 }
 
 impl Field {
@@ -50,6 +53,7 @@ impl Field {
         Self {
             name: String::from(name),
             content_type: ContentType::Text,
+            of: None,
         }
     }
 
@@ -57,6 +61,15 @@ impl Field {
         Self {
             name: String::from(name),
             content_type: ContentType::Image,
+            of: None,
+        }
+    }
+
+    pub fn reference(name: &str, of: &Model) -> Self {
+        Self {
+            name: String::from(name),
+            content_type: ContentType::Reference,
+            of: Some(of.name.clone()),
         }
     }
 }
