@@ -21,12 +21,17 @@ pub async fn static_file(
     web::Path(filename): web::Path<String>,
     context: web::Data<AppContext>,
 ) -> impl Responder {
+    let mime = match filename.ends_with(".js") {
+        true => "text/javascript",
+        false => "text",
+    };
+
     match read_to_string(format!("{}/public/{}", context.root, filename).as_str()) {
         Ok(html) => HttpResponse::Ok()
             .body(html)
-            .with_header("Content-Type", "text/html"),
+            .with_header("Content-Type", mime),
         _ => HttpResponse::NotFound()
             .body("Not Found")
-            .with_header("Content-Type", "text/html"),
+            .with_header("Content-Type", mime),
     }
 }
